Module tezos_smart_rollup::dac

source ·
Defines dac related types and functions.

Modules

  • Encoding of Dac certificates. Dac certificates are versioned: the first byte in a serialized Dac certificate is indicative of the version of the certificate itself.
  • Encoding of DAC payload as a Merkle tree with an arbitrary branching factor greater or equal to 2. The serialization process works as follows:

Structs

Enums

Constants

Functions