pub enum CertificateError {
InsufficientNumberOfSignatures {
threshold: usize,
actual: usize,
},
SignatureVerificationFailed(CryptoError),
InvalidAggregateSignature,
StorageError(String, RuntimeError),
RevealError(PreimageHash, RuntimeError),
PageError(SlicePageError),
PayloadTooLarge,
}Expand description
Errors that can be obtained when handling a certificate.
Variants
InsufficientNumberOfSignatures
Fields
Number of signatures is lower than the required threshold
SignatureVerificationFailed(CryptoError)
Cryptographic primitives result in error while verifying the signature
InvalidAggregateSignature
Signature Verification failed
StorageError(String, RuntimeError)
Storage error when revealing a certificate
RevealError(PreimageHash, RuntimeError)
Error occurred revealing page of content
PageError(SlicePageError)
Revealed page has invalid encoding
PayloadTooLarge
Revealed content is/would be larger than 10,063,860 bytes