Struct tezos_smart_rollup::dac::V0ContentPage
source · pub struct V0ContentPage { /* private fields */ }Expand description
Content page consisting of a dynamic number of bytes.
Implementations
sourceimpl V0ContentPage
impl V0ContentPage
sourcepub const MAX_CONTENT_SIZE: usize = 4_091usize
pub const MAX_CONTENT_SIZE: usize = 4_091usize
Maximum size of content in each page.
sourcepub fn new_pages(input: &[u8]) -> impl Iterator<Item = V0ContentPage>
pub fn new_pages(input: &[u8]) -> impl Iterator<Item = V0ContentPage>
Serialize an input slice into a sequence of content pages.