Struct tezos_smart_rollup::dac::V0HashPage
source · pub struct V0HashPage { /* private fields */ }Expand description
Hash page consisting of a dynamic number of PreimageHash.
Implementations
sourceimpl V0HashPage
impl V0HashPage
sourcepub const MAX_HASHES_PER_PAGE: usize = 123usize
pub const MAX_HASHES_PER_PAGE: usize = 123usize
Maximum number of hashes able to fit into a hash page.
sourcepub fn hashes(&self) -> &[PreimageHash]
pub fn hashes(&self) -> &[PreimageHash]
The list of hashes.