#[repr(i32)]
pub enum HostError { StoreKeyTooLarge = -1, StoreInvalidKey = -2, StoreNotAValue = -3, StoreInvalidAccess = -4, StoreValueSizeExceeded = -5, MemoryInvalidAccess = -6, InputOutputTooLarge = -7, GenericInvalidAccess = -8, StoreReadonlyValue = -9, StoreNotANode = -10, FullOutbox = -11, }
Defines the errors possibly returned by an host functions.

Variants



StoreKeyTooLarge = -1

The store key submitted as an argument of a host function exceeds the authorized limit.



StoreInvalidKey = -2

The store key submitted as an argument of a host function cannot be parsed.



StoreNotAValue = -3

The contents (if any) of the store under the key submitted as an argument of a host function is not a value.



StoreInvalidAccess = -4

An access in a value of the durable storage has failed, supposedly out of bounds of a value.



StoreValueSizeExceeded = -5

Writing a value has exceeded 2^31 bytes.



MemoryInvalidAccess = -6

An address is out of bound of the memory.



InputOutputTooLarge = -7

The input or output submitted as an argument of a host function exceeds the authorized limit.



GenericInvalidAccess = -8

Generic error code for unexpected errors.



StoreReadonlyValue = -9

A value cannot be modified if it is readonly.



StoreNotANode = -10

The key was not found in storage



FullOutbox = -11

The outbox is full

Implementations

source

impl Error

source

pub fn wrap(code: i32) -> Result<usize, Error>

Extracts the error from the returned value as a result

source

pub fn code(self) -> i32

Returns the code for the given error.