pub enum InternalInboxMessage<Expr>where
Expr: Michelson,{
Transfer(Transfer<Expr>),
StartOfLevel,
EndOfLevel,
InfoPerLevel(InfoPerLevel),
}Expand description
Internal inbox message - known to be sent by the protocol
Variants
Transfer(Transfer<Expr>)
Transfer message
StartOfLevel
Start of level message, pushed at the beginning of an inbox level.
EndOfLevel
End of level message, pushed at the end of an inbox level.
InfoPerLevel(InfoPerLevel)
Info per level, goes after StartOfLevel