Type Definition tezos_smart_rollup::michelson::ticket::StringTicket
source · pub type StringTicket = Ticket<MichelsonString>;Expand description
Specialized version of ticket where the content must be a string
pub type StringTicket = Ticket<MichelsonString>;Specialized version of ticket where the content must be a string