Module tezos_smart_rollup::storage::path
source · Expand description
Enforcing correct encoding of storage paths.
A storage path can be written to, or read from by the kernel - and may correspond to a sequence of bytes in the runtime storage.
Structs
- Representation of a
Pathwhich owns its underlying path-encoded byte sequence. - Representation of a
Pathwhich borrows its underlying byte-sequence.
Enums
- Possible path validation errors.
Constants
- The wasm-encoded binary blob of either the currently running kernel, or the next kernel to be rebooted into.
- The maximum size (in bytes) of a path.
- The separator byte between steps in a path.
Traits
- Marker trait for methods on types representing path-encodings.
Functions
- Given a prefix and a suffix create a new path that concatenates the two.