Function tezos_smart_rollup::storage::path::concat
source · pub fn concat(
prefix: &impl Path,
suffix: &impl Path
) -> Result<OwnedPath, PathError>Expand description
Given a prefix and a suffix create a new path that concatenates the two.
Returns error in case the resulting path is too long.