Module tezos_smart_rollup::testing
source · Expand description
Utilities for writing unit tests for kernels.
In particular, MockHost simulates the host functions
exposed by the Smart Rollups, to allow full end-to-end
testing of a kernel’s behaviour.
Modules
- Mock runtime provides a host that can used in integration & unit testing of kernels for Tezos Smart Rollups.