pub enum PathError {
    PathEmpty,
    PathTooLong,
    InvalidStart,
    InvalidEmptyStep,
    InvalidByteInStep,
    ReadOnly,
}
Possible path validation errors.

Variants



PathEmpty

Path contains no steps.



PathTooLong

Path must be at most PATH_MAX_SIZE bytes in size.



InvalidStart

Path must begin with PATH_SEPARATOR.



InvalidEmptyStep

Path must not contain empty steps.



InvalidByteInStep

Steps must be a sequence of bytes such that every byte is in [A-Za-z0-9.]



ReadOnly

The given path starts with /readonly which is prohibited. Use the specific function to read from that part of the storage.